package com.muyu.many.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.many.domain.req.MessageDataEditReq;
import com.muyu.many.domain.req.MessageDataQueryReq;
import com.muyu.many.domain.req.MessageDataSaveReq;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.muyu.common.core.annotation.Excel;
import com.muyu.common.core.web.domain.BaseEntity;

/**
 * 报文类型数据对象 message_data
 *
 * @author wan
 * @date 2024-06-28
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("message_data")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "MessageDataArgument", description = "报文类型数据")
public class MessageData extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** 主键 */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "主键", value = "主键")
    private Long id;

    /** 报文标签 */
    @Excel(name = "报文标签")
    @ApiModelProperty(name = "报文标签", value = "报文标签")
    private String messageLabel;

    /** 指标Key */
    @Excel(name = "指标Key")
    @ApiModelProperty(name = "指标Key", value = "指标Key")
    private String analyzeKey;

    /** 起始位 */
    @Excel(name = "起始位")
    @ApiModelProperty(name = "起始位", value = "起始位")
    private String initiationPosition;

    /** 终止位 */
    @Excel(name = "终止位")
    @ApiModelProperty(name = "终止位", value = "终止位")
    private String terminatePosition;

    /** 报文类型 */
    @Excel(name = "报文类型")
    @ApiModelProperty(name = "报文类型", value = "报文类型")
    private String typeIdentification;

    /**
    * 查询构造器
    */
    public static MessageData queryBuild(MessageDataQueryReq messageDataQueryReq){
        return MessageData.builder()
                .messageLabel(messageDataQueryReq.getMessageLabel())
                .analyzeKey(messageDataQueryReq.getAnalyzeKey())
                .initiationPosition(messageDataQueryReq.getInitiationPosition())
                .terminatePosition(messageDataQueryReq.getTerminatePosition())
                .typeIdentification(messageDataQueryReq.getTypeIdentification())
                .build();
    }

    /**
    * 添加构造器
    */
    public static MessageData saveBuild(MessageDataSaveReq messageDataSaveReq){
        return MessageData.builder()
                .messageLabel(messageDataSaveReq.getMessageLabel())
                .analyzeKey(messageDataSaveReq.getAnalyzeKey())
                .initiationPosition(messageDataSaveReq.getInitiationPosition())
                .terminatePosition(messageDataSaveReq.getTerminatePosition())
                .typeIdentification(messageDataSaveReq.getTypeIdentification())
                .build();
    }

    /**
    * 修改构造器
    */
    public static MessageData editBuild(Long id, MessageDataEditReq messageDataEditReq){
        return MessageData.builder()
            .id(id)
                .messageLabel(messageDataEditReq.getMessageLabel())
                .analyzeKey(messageDataEditReq.getAnalyzeKey())
                .initiationPosition(messageDataEditReq.getInitiationPosition())
                .terminatePosition(messageDataEditReq.getTerminatePosition())
                .typeIdentification(messageDataEditReq.getTypeIdentification())
                .build();
    }

}
