package com.muyu.authentication.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.authentication.service.MessageAnalysisService;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.many.domain.MessageAnalysis;
import com.muyu.many.domain.req.MessageAnalysisEditReq;
import com.muyu.many.domain.req.MessageAnalysisQueryReq;
import com.muyu.many.domain.req.MessageAnalysisSaveReq;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;

/**
 * 报文解析Controller
 *
 * @author wan
 * @date 2024-06-28
 */
@Api(tags = "报文解析")
@RestController
@RequestMapping("/analysis")
public class MessageAnalysisController extends BaseController {
    @Autowired
    private MessageAnalysisService messageAnalysisService;

    /**
     * 查询报文解析列表
     */
    @ApiOperation("获取报文解析列表")
    @GetMapping("/list")
    public Result<TableDataInfo<MessageAnalysis>> list(MessageAnalysisQueryReq messageAnalysisQueryReq) {
        startPage();
        List<MessageAnalysis> list = messageAnalysisService.list(MessageAnalysis.queryBuild(messageAnalysisQueryReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return getDataTable(list);
    }

    /**
     * 导出报文解析列表
     */
    @ApiOperation("导出报文解析列表")
    @Log(title = "报文解析", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MessageAnalysis messageAnalysis) {
        List<MessageAnalysis> list = messageAnalysisService.list(messageAnalysis);
        ExcelUtil<MessageAnalysis> util = new ExcelUtil<MessageAnalysis>(MessageAnalysis.class);
        util.exportExcel(response, list, "报文解析数据");
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
    }

    /**
     * 获取报文解析详细信息
     */
    @ApiOperation("获取报文解析详细信息")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<MessageAnalysis> getInfo(@PathVariable("id") Long id) {
        MessageAnalysis byId = messageAnalysisService.getById(id);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(byId);
    }

    /**
     * 新增报文解析
     */
    @Log(title = "报文解析", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增报文解析")
    public Result<String> add(@RequestBody MessageAnalysisSaveReq messageAnalysisSaveReq) {
        boolean save = messageAnalysisService.save(MessageAnalysis.saveBuild(messageAnalysisSaveReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(save);
    }

    /**
     * 修改报文解析
     */
    @Log(title = "报文解析", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改报文解析")
    public Result<String> edit(@PathVariable Long id, @RequestBody MessageAnalysisEditReq messageAnalysisEditReq) {
        boolean b = messageAnalysisService.updateById(MessageAnalysis.editBuild(id, messageAnalysisEditReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    /**
     * 删除报文解析
     */
    @Log(title = "报文解析", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除报文解析")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        boolean b = messageAnalysisService.removeBatchByIds(ids);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    @GetMapping("/messageAnalysisList")
    public Result<List<MessageAnalysis>>messageAnalysisList(){
        List<MessageAnalysis> messageAnalyses = messageAnalysisService.messageAnalysisList();
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(messageAnalyses);
    }
}
