package com.muyu.authentication.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.authentication.service.MessageConfigurationTypeService;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.many.domain.MessageConfigurationType;
import com.muyu.many.domain.req.MessageConfigurationTypeEditReq;
import com.muyu.many.domain.req.MessageConfigurationTypeQueryReq;
import com.muyu.many.domain.req.MessageConfigurationTypeSaveReq;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;

/**
 * 报文配置类型Controller
 *
 * @author wan
 * @date 2024-06-28
 */
@Api(tags = "报文配置类型")
@RestController
@RequestMapping("/configuration")
public class MessageConfigurationTypeController extends BaseController {
    @Autowired
    private MessageConfigurationTypeService messageConfigurationTypeService;

    /**
     * 查询报文配置类型列表
     */
    @ApiOperation("获取报文配置类型列表")
    @GetMapping("/list")
    public Result<TableDataInfo<MessageConfigurationType>> list(MessageConfigurationTypeQueryReq messageConfigurationTypeQueryReq) {
        startPage();
        List<MessageConfigurationType> list = messageConfigurationTypeService.list(MessageConfigurationType.queryBuild(messageConfigurationTypeQueryReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return getDataTable(list);
    }

    /**
     * 导出报文配置类型列表
     */
    @ApiOperation("导出报文配置类型列表")
    @Log(title = "报文配置类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MessageConfigurationType messageConfigurationType) {
        List<MessageConfigurationType> list = messageConfigurationTypeService.list(messageConfigurationType);
        ExcelUtil<MessageConfigurationType> util = new ExcelUtil<MessageConfigurationType>(MessageConfigurationType.class);
        util.exportExcel(response, list, "报文配置类型数据");
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
    }

    /**
     * 获取报文配置类型详细信息
     */
    @ApiOperation("获取报文配置类型详细信息")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<MessageConfigurationType> getInfo(@PathVariable("id") Long id) {
        MessageConfigurationType byId = messageConfigurationTypeService.getById(id);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(byId);
    }

    /**
     * 新增报文配置类型
     */
    @Log(title = "报文配置类型", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增报文配置类型")
    public Result<String> add(@RequestBody MessageConfigurationTypeSaveReq messageConfigurationTypeSaveReq) {
        boolean save = messageConfigurationTypeService.save(MessageConfigurationType.saveBuild(messageConfigurationTypeSaveReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(save);
    }

    /**
     * 修改报文配置类型
     */
    @Log(title = "报文配置类型", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改报文配置类型")
    public Result<String> edit(@PathVariable Long id, @RequestBody MessageConfigurationTypeEditReq messageConfigurationTypeEditReq) {
        boolean b = messageConfigurationTypeService.updateById(MessageConfigurationType.editBuild(id, messageConfigurationTypeEditReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    /**
     * 删除报文配置类型
     */
    @Log(title = "报文配置类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除报文配置类型")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        boolean b = messageConfigurationTypeService.removeBatchByIds(ids);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }
}
