package com.muyu.authentication.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.authentication.service.MessageDataService;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.many.domain.MessageAnalysis;
import com.muyu.many.domain.MessageData;
import com.muyu.many.domain.req.MessageDataEditReq;
import com.muyu.many.domain.req.MessageDataEnterprise;
import com.muyu.many.domain.req.MessageDataQueryReq;
import com.muyu.many.domain.req.MessageDataSaveReq;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;

/**
 * 报文类型数据Controller
 *
 * @author wan
 * @date 2024-06-28
 */
@Api(tags = "报文类型数据")
@RestController
@RequestMapping("/message")
public class MessageDataController extends BaseController {
    @Autowired
    private MessageDataService messageDataService;

    /**
     * 查询报文类型数据列表
     */
    @ApiOperation("获取报文类型数据列表")
    @GetMapping("/list")
    public Result<TableDataInfo<MessageData>> list(MessageDataQueryReq messageDataQueryReq) {
        startPage();
        List<MessageData> list = messageDataService.list(MessageData.queryBuild(messageDataQueryReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return getDataTable(list);
    }

    /**
     * 导出报文类型数据列表
     */
    @ApiOperation("导出报文类型数据列表")
    @Log(title = "报文类型数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MessageData messageData) {
        List<MessageData> list = messageDataService.list(messageData);
        ExcelUtil<MessageData> util = new ExcelUtil<MessageData>(MessageData.class);
        util.exportExcel(response, list, "报文类型数据数据");
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
    }

    /**
     * 获取报文类型数据详细信息
     */
    @ApiOperation("获取报文类型数据详细信息")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<MessageData> getInfo(@PathVariable("id") Long id) {
        MessageData byId = messageDataService.getById(id);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(byId);
    }

    /**
     * 新增报文类型数据
     */
    @Log(title = "报文类型数据", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增报文类型数据")
    public Result<String> add(@RequestBody MessageDataSaveReq messageDataSaveReq) {
        boolean save = messageDataService.save(MessageData.saveBuild(messageDataSaveReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(save);
    }

    /**
     * 修改报文类型数据
     */
    @Log(title = "报文类型数据", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改报文类型数据")
    public Result<String> edit(@PathVariable Long id, @RequestBody MessageDataEditReq messageDataEditReq) {
        boolean b = messageDataService.updateById(MessageData.editBuild(id, messageDataEditReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    /**
     * 删除报文类型数据
     */
    @Log(title = "报文类型数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除报文类型数据")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        boolean b = messageDataService.removeBatchByIds(ids);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    @GetMapping("/messageList")
    public Result<List<MessageData>> messageList(){
        List<MessageData> list = messageDataService.list();
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(list);
    }

    @PostMapping("/messageDataEnterpriseAdd")
    public void messageDataEnterpriseAdd(@RequestBody MessageDataEnterprise messageDataEnterprise){
        messageDataService.messageDataEnterpriseAdd(messageDataEnterprise);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
    }


}
