package com.muyu.authentication.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.authentication.service.SlideLengthService;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.many.domain.SlideLength;
import com.muyu.many.domain.Window;
import com.muyu.many.domain.req.SlideLengthEditReq;
import com.muyu.many.domain.req.SlideLengthQueryReq;
import com.muyu.many.domain.req.SlideLengthSaveReq;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 滑动长度Controller
 *
 * @author wan
 * @date 2024-06-29
 */
@Api(tags = "滑动长度")
@RestController
@RequestMapping("/SlideLength")
public class SlideLengthController extends BaseController {
    @Autowired
    private SlideLengthService slideLengthService;

    /**
     * 查询滑动长度列表
     */
    @ApiOperation("获取滑动长度列表")
    @GetMapping("/list")
    public Result<TableDataInfo<SlideLength>> list(SlideLengthQueryReq slideLengthQueryReq) {
        startPage();
        List<SlideLength> list = slideLengthService.list(SlideLength.queryBuild(slideLengthQueryReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return getDataTable(list);
    }

    /**
     * 导出滑动长度列表
     */
    @ApiOperation("导出滑动长度列表")
    @Log(title = "滑动长度", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SlideLength slideLength) {
        List<SlideLength> list = slideLengthService.list(slideLength);
        ExcelUtil<SlideLength> util = new ExcelUtil<SlideLength>(SlideLength.class);
        util.exportExcel(response, list, "滑动长度数据");
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
    }

    /**
     * 获取滑动长度详细信息
     */
    @ApiOperation("获取滑动长度详细信息")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<SlideLength> getInfo(@PathVariable("id") Long id) {

        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(slideLengthService.getById(id));
    }

    /**
     * 新增滑动长度
     */
    @Log(title = "滑动长度", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增滑动长度")
    public Result<String> add(@RequestBody SlideLengthSaveReq slideLengthSaveReq) {
        boolean save = slideLengthService.save(SlideLength.saveBuild(slideLengthSaveReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(save);
    }

    /**
     * 修改滑动长度
     */
    @Log(title = "滑动长度", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改滑动长度")
    public Result<String> edit(@PathVariable Long id, @RequestBody SlideLengthEditReq slideLengthEditReq) {
        boolean b = slideLengthService.updateById(SlideLength.editBuild(id, slideLengthEditReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    /**
     * 删除滑动长度
     */
    @Log(title = "滑动长度", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除滑动长度")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        boolean b = slideLengthService.removeBatchByIds(ids);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    @GetMapping("/slideLengthList")
    public Result<List<SlideLength>> windowList(){
        List<SlideLength> slideLengthList = slideLengthService.slideLengthList();
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(slideLengthList);
    }
}
