package com.muyu.authentication.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.authentication.service.SlidingInfoService;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.many.domain.SlidingInfo;
import com.muyu.many.domain.req.SlidingInfoEditReq;
import com.muyu.many.domain.req.SlidingInfoQueryReq;
import com.muyu.many.domain.req.SlidingInfoSaveReq;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 滑窗Controller
 *
 * @author wan
 * @date 2024-06-29
 */
@Api(tags = "滑窗")
@RestController
@RequestMapping("/SlidingInfo")
public class SlidingInfoController extends BaseController {
    @Autowired
    private SlidingInfoService slidingInfoService;

    /**
     * 查询滑窗列表
     */
    @ApiOperation("获取滑窗列表")
    @GetMapping("/list")
    public Result<TableDataInfo<SlidingInfo>> list(SlidingInfoQueryReq slidingInfoQueryReq) {
        startPage();
        List<SlidingInfo> list = slidingInfoService.list(SlidingInfo.queryBuild(slidingInfoQueryReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return getDataTable(list);
    }

    /**
     * 导出滑窗列表
     */
    @ApiOperation("导出滑窗列表")
    @Log(title = "滑窗", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SlidingInfo slidingInfo) {
        List<SlidingInfo> list = slidingInfoService.list(slidingInfo);
        ExcelUtil<SlidingInfo> util = new ExcelUtil<SlidingInfo>(SlidingInfo.class);
        util.exportExcel(response, list, "滑窗数据");
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
    }

    /**
     * 获取滑窗详细信息
     */
    @ApiOperation("获取滑窗详细信息")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<SlidingInfo> getInfo(@PathVariable("id") Long id) {
        SlidingInfo byId = slidingInfoService.getById(id);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(byId);
    }

    /**
     * 新增滑窗
     */
    @Log(title = "滑窗", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增滑窗")
    public Result<String> add(@RequestBody SlidingInfoSaveReq slidingInfoSaveReq) {
        boolean add = slidingInfoService.add(SlidingInfo.saveBuild(slidingInfoSaveReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(add);
    }

    /**
     * 修改滑窗
     */
    @Log(title = "滑窗", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改滑窗")
    public Result<String> edit(@PathVariable Long id, @RequestBody SlidingInfoEditReq slidingInfoEditReq) {
        boolean b = slidingInfoService.updateId(SlidingInfo.editBuild(id, slidingInfoEditReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    /**
     * 删除滑窗
     */
    @Log(title = "滑窗", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除滑窗")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        boolean b = slidingInfoService.removeBatchByIds(ids);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }
}
