package com.muyu.authentication.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.authentication.service.WindowService;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.many.domain.Window;
import com.muyu.many.domain.req.WindowEditReq;
import com.muyu.many.domain.req.WindowQueryReq;
import com.muyu.many.domain.req.WindowSaveReq;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 滑窗范围Controller
 *
 * @author wan
 * @date 2024-06-29
 */
@Api(tags = "滑窗范围")
@RestController
@RequestMapping("/Window")
public class WindowController extends BaseController {
    @Autowired
    private WindowService windowService;

    /**
     * 查询滑窗范围列表
     */
    @ApiOperation("获取滑窗范围列表")
    @GetMapping("/list")
    public Result<TableDataInfo<Window>> list(WindowQueryReq windowQueryReq) {
        startPage();
        List<Window> list = windowService.list(Window.queryBuild(windowQueryReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return getDataTable(list);
    }

    /**
     * 导出滑窗范围列表
     */
    @ApiOperation("导出滑窗范围列表")
    @Log(title = "滑窗范围", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Window window) {
        List<Window> list = windowService.list(window);
        ExcelUtil<Window> util = new ExcelUtil<Window>(Window.class);
        util.exportExcel(response, list, "滑窗范围数据");
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
    }

    /**
     * 获取滑窗范围详细信息
     */
    @ApiOperation("获取滑窗范围详细信息")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<Window> getInfo(@PathVariable("id") Long id) {
        Window byId = windowService.getById(id);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(byId);
    }

    /**
     * 新增滑窗范围
     */
    @Log(title = "滑窗范围", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增滑窗范围")
    public Result<String> add(@RequestBody WindowSaveReq windowSaveReq) {
        boolean save = windowService.save(Window.saveBuild(windowSaveReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(save);
    }

    /**
     * 修改滑窗范围
     */
    @Log(title = "滑窗范围", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改滑窗范围")
    public Result<String> edit(@PathVariable Long id, @RequestBody WindowEditReq windowEditReq) {
        boolean b = windowService.updateById(Window.editBuild(id, windowEditReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    /**
     * 删除滑窗范围
     */
    @Log(title = "滑窗范围", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除滑窗范围")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        boolean b = windowService.removeBatchByIds(ids);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    @GetMapping("/windowList")
    public Result<List<Window>> windowList(){
        List<Window> windows = windowService.windowList();
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(windows);
    }
}
