package com.muyu.authentication.service.impl;

import java.util.List;

import com.muyu.authentication.service.MessageAnalysisService;
import com.muyu.common.core.utils.ObjUtils;
import com.muyu.many.domain.MessageAnalysis;
import com.muyu.authentication.mapper.MessageAnalysisMapper;

import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;

/**
 * 报文解析Service业务层处理
 *
 * @author wan
 * @date 2024-06-28
 */
@Slf4j
@Service
public class MessageAnalysisServiceImpl extends ServiceImpl<MessageAnalysisMapper, MessageAnalysis>  implements MessageAnalysisService {

    /**
     * 查询报文解析列表
     *
     * @param messageAnalysis 报文解析
     * @return 报文解析
     */
    @Override
    public List<MessageAnalysis> list(MessageAnalysis messageAnalysis) {
        LambdaQueryWrapper<MessageAnalysis> queryWrapper = new LambdaQueryWrapper<>();

        if (ObjUtils.notNull(messageAnalysis.getVehicleId())){
            queryWrapper.eq(MessageAnalysis::getVehicleId, messageAnalysis.getVehicleId());
        }

        if (ObjUtils.notNull(messageAnalysis.getAnalyzeKey())){
            queryWrapper.eq(MessageAnalysis::getAnalyzeKey, messageAnalysis.getAnalyzeKey());
        }

        if (ObjUtils.notNull(messageAnalysis.getAnalyzeStart())){
            queryWrapper.eq(MessageAnalysis::getAnalyzeStart, messageAnalysis.getAnalyzeStart());
        }

        if (ObjUtils.notNull(messageAnalysis.getEnt())){
            queryWrapper.eq(MessageAnalysis::getEnt, messageAnalysis.getEnt());
        }

        if (ObjUtils.notNull(messageAnalysis.getLable())){
            queryWrapper.eq(MessageAnalysis::getLable, messageAnalysis.getLable());
        }

        if (ObjUtils.notNull(messageAnalysis.getType())){
            queryWrapper.eq(MessageAnalysis::getType, messageAnalysis.getType());
        }
        return list(queryWrapper);
    }

    @Autowired
    private MessageAnalysisMapper messageAnalysis;

    @Override
    public List<MessageAnalysis> messageAnalysisList() {
        return messageAnalysis.selectList(null);
    }
}
