package com.muyu.authentication.service.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.authentication.mapper.MessageAnalysisMapper;
import com.muyu.authentication.mapper.MessageDataMapper;
import com.muyu.authentication.mapper.VehicleMapper;
import com.muyu.authentication.service.MessageDataService;
import com.muyu.common.core.utils.ObjUtils;
import com.muyu.domain.Enterprise;
import com.muyu.many.domain.MessageAnalysis;
import com.muyu.many.domain.MessageData;
import com.muyu.many.domain.Vehicle;
import com.muyu.many.domain.req.MessageDataEnterprise;
import com.muyu.many.domain.req.MessageDataEnterpriseMq;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;

/**
 * 报文类型数据Service业务层处理
 *
 * @author wan
 * @date 2024-06-28
 */
@Slf4j
@Service
public class MessageDataServiceImpl extends ServiceImpl<MessageDataMapper, MessageData> implements MessageDataService {

    /**
     * 查询报文类型数据列表
     *
     * @param messageData 报文类型数据
     * @return 报文类型数据
     */
    @Override
    public List<MessageData> list(MessageData messageData) {
        LambdaQueryWrapper<MessageData> queryWrapper = new LambdaQueryWrapper<>();


        if (ObjUtils.notNull(messageData.getMessageLabel())){
            queryWrapper.eq(MessageData::getMessageLabel, messageData.getMessageLabel());
        }

        if (ObjUtils.notNull(messageData.getAnalyzeKey())){
            queryWrapper.eq(MessageData::getAnalyzeKey, messageData.getAnalyzeKey());
        }

        if (ObjUtils.notNull(messageData.getInitiationPosition())){
            queryWrapper.eq(MessageData::getInitiationPosition, messageData.getInitiationPosition());
        }

        if (ObjUtils.notNull(messageData.getTerminatePosition())){
            queryWrapper.eq(MessageData::getTerminatePosition, messageData.getTerminatePosition());
        }

        if (ObjUtils.notNull(messageData.getTypeIdentification())){
            queryWrapper.eq(MessageData::getTypeIdentification, messageData.getTypeIdentification());
        }





        return list(queryWrapper);
    }




    @Autowired
    private MessageAnalysisMapper messageAnalysisMapper;
    @Autowired
    private MessageDataMapper messageDataMapper;
    @Autowired
    private VehicleMapper vehicleMapper;
    @Autowired
    private StringRedisTemplate redisTemplate;

    @Override
    public void messageDataEnterpriseAdd(MessageDataEnterprise messageDataEnterprise) {
        List<MessageData> messageData = messageDataList(messageDataEnterprise.getIds());

        messageData.forEach(message -> {
            messageAnalysisMapper.insert(
                    MessageAnalysis.builder()
                            .vehicleId(messageDataEnterprise.getId())
                            .analyzeKey(message.getAnalyzeKey())
                            .analyzeStart(Long.valueOf(message.getInitiationPosition()))
                            .ent(Long.valueOf(message.getTerminatePosition()))
                            .lable(message.getMessageLabel())
                            .type(message.getRemark())
                            .build()
        );
        });
        List<Vehicle> vehicles = vehicleMapper.selectList(null);


        vehicles.forEach(vehicl -> {
            List<MessageAnalysis> messageAnalyses = messageAnalysisMapper.selectList(
                    new LambdaQueryWrapper<>() {{
                        eq(MessageAnalysis::getVehicleId, vehicl.getId());
                        ;
                    }}
            );
            List<MessageAnalysis> arrayList = new ArrayList<>();
            messageAnalyses.forEach(messageAnal->{
                arrayList.add(messageAnal);
            });
            String jsonString = JSON.toJSONString(arrayList);
            System.out.println(jsonString);
            redisTemplate.opsForHash().put("VIN",vehicl.getVin(),jsonString);
        });
    }

    private List<MessageData> messageDataList(List<Long> ids){
        List<MessageData> arrayList = new ArrayList<>();
        for (Long id : ids) {
            MessageData messageData = messageDataMapper.selectOne(
                    new LambdaQueryWrapper<>() {{
                        eq(MessageData::getId, id);
                    }}
            );
            arrayList.add(messageData);
        }
        return arrayList;
    }

}
