package com.muyu.authentication.service.impl;

import java.util.List;
import java.util.UUID;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.authentication.mapper.SlideLengthMapper;
import com.muyu.authentication.mapper.SlidingInfoMapper;
import com.muyu.authentication.mapper.WindowMapper;
import com.muyu.authentication.service.SlidingInfoService;
import com.muyu.common.core.utils.ObjUtils;
import com.muyu.many.domain.SlideLength;
import com.muyu.many.domain.SlidingInfo;
import com.muyu.many.domain.Window;
import com.muyu.many.domain.mq.MessageAnalysisMq;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;

/**
 * 滑窗Service业务层处理
 *
 * @author wan
 * @date 2024-06-29
 */
@Slf4j
@Service
public class SlidingInfoServiceImpl extends ServiceImpl<SlidingInfoMapper, SlidingInfo> implements SlidingInfoService {

    @Autowired
    private SlidingInfoMapper slidingInfoMapper;
    /**
     * 查询滑窗列表
     *
     * @param slidingInfo 滑窗
     * @return 滑窗
     */
    @Override
    public List<SlidingInfo> list(SlidingInfo slidingInfo) {
        LambdaQueryWrapper<SlidingInfo> queryWrapper = new LambdaQueryWrapper<>();


        if (ObjUtils.notNull(slidingInfo.getVehicleVin())){
            queryWrapper.eq(SlidingInfo::getVehicleVin, slidingInfo.getVehicleVin());
        }
        return list(queryWrapper);
    }

    @Autowired
    private WindowMapper windowMapper;
    @Autowired
    private SlideLengthMapper slideLengthMapper;
    @Autowired
    private RabbitTemplate rabbitTemplate;
    @Autowired
    private StringRedisTemplate redisTemplate;

    @Override
    public boolean add(SlidingInfo slidingInfo) {
        int insert = slidingInfoMapper.insert(slidingInfo);
        if (insert>0) {

            Window window = windowMapper.selectById(slidingInfo.getWindowRadiusId());
            SlideLength slideLength = slideLengthMapper.selectById(slidingInfo.getSlideLengthId());

            MessageAnalysisMq build = MessageAnalysisMq.builder()
                    .vehicleVin(slidingInfo.getVehicleVin())
                    .analyzeKey(slidingInfo.getAnalyzeKey())
                    .messageLabel(slidingInfo.getMessageLabel())
                    .standard(slidingInfo.getStandard())
                    .windowRadiusId(window.getWindowRadiusLength())
                    .slideLengthId(slideLength.getSlideLengthProportion())
                    .build();
            redisTemplate.opsForValue().set(build.getVehicleVin()+"-length",JSON.toJSONString(build));
            return true;
        }
        return false;
    }


    @Override
    public boolean updateId(SlidingInfo slidingInfo) {
        int i = slidingInfoMapper.updateById(slidingInfo);

        if (i>0) {
            redisTemplate.delete(slidingInfo.getVehicleVin()+"-length");
            Window window = windowMapper.selectById(slidingInfo.getWindowRadiusId());
            SlideLength slideLength = slideLengthMapper.selectById(slidingInfo.getSlideLengthId());

            MessageAnalysisMq build = MessageAnalysisMq.builder()
                    .vehicleVin(slidingInfo.getVehicleVin())
                    .analyzeKey(slidingInfo.getAnalyzeKey())
                    .messageLabel(slidingInfo.getMessageLabel())
                    .standard(slidingInfo.getStandard())
                    .windowRadiusId(window.getWindowRadiusLength())
                    .slideLengthId(slideLength.getSlideLengthProportion())
                    .build();
            redisTemplate.opsForValue().set(build.getVehicleVin()+"-length",JSON.toJSONString(build));
            String s = build.getVehicleVin() + "-length";
            rabbitTemplate.convertAndSend("renew",s,message -> {
                message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
                return message;
            });
            return true;
        }
        return false;
    }
}
